==> pochy-0.1.5-src.tar.gz: pochy-0.1.5-src/SettingGeneralDlg.cpp <==
/*
 * Copyright (C) 2002-2003 chik, s.hiranaka
 * For license terms, see the file COPYING in this directory.
 */

// SettingGeneralDlg.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "SettingGeneralDlg.h"
#include "SettingGeneralAppearanceDlg.h"
#include "SettingGeneralOtherDlg.h"
#include "MainFrm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CSettingGeneralDlg _CAO


CSettingGeneralDlg::CSettingGeneralDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSettingGeneralDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSettingGeneralDlg)
		//  - ClassWizard ͂̈ʒuɃ}bsOp̃}Nǉ܂͍폜܂B
	//}}AFX_DATA_INIT
}


void CSettingGeneralDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSettingGeneralDlg)
	DDX_Control(pDX, IDC_SETTING_GENERAL_TAB, m_tab);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CSettingGeneralDlg, CDialog)
	//{{AFX_MSG_MAP(CSettingGeneralDlg)
	ON_NOTIFY(TCN_SELCHANGE, IDC_SETTING_GENERAL_TAB, OnSelchangeTab)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSettingGeneralDlg bZ[W nh

BOOL CSettingGeneralDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();
	
	TC_ITEM item;  //^uACe\
	//^uRg[ɍڂ̒ǉ
	item.mask = TCIF_TEXT;
	item.pszText = "FEtHg"; //^ǔo̐ݒ
	m_tab.InsertItem(0, &item); //^uRg[ɍڂ}

	item.pszText = "̑";
	m_tab.InsertItem(1, &item);

	// ^uRg[eEBhEƂĊe^uy[W쐬
	m_appearance_dlg.Create(IDD_SETTING_GENERAL_APPEARANCE, &m_tab);
	m_other_dlg.Create(IDD_SETTING_GENERAL_OTHER, &m_tab);

	//\Ԃ̐ݒ
	m_appearance_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);
	m_other_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);

	m_appearance_dlg.ShowWindow(SW_SHOW);
	m_other_dlg.ShowWindow(SW_HIDE);

	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
}

void CSettingGeneralDlg::OnSelchangeTab(NMHDR* pNMHDR, LRESULT* pResult) 
{
	int index = m_tab.GetCurSel(); //؂ւOTabIndexԍ
	//IꂽTab̂ݕ\B
	switch(index){
	case 0:
		m_appearance_dlg.ShowWindow(SW_SHOW);
		m_other_dlg.ShowWindow(SW_HIDE);
		break;
	case 1:
		m_appearance_dlg.ShowWindow(SW_HIDE);
		m_other_dlg.ShowWindow(SW_SHOW);
		break;
	}

	*pResult = 0;
}

void CSettingGeneralDlg::OnOK() 
{
	CPochyApp* app = (CPochyApp*)AfxGetApp();
	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;

	// folderview̔wiF
	app->WriteProfileInt("FolderViewColor","BkColorR",GetRValue(m_appearance_dlg.m_fv_bg_cr));
	app->WriteProfileInt("FolderViewColor","BkColorG",GetGValue(m_appearance_dlg.m_fv_bg_cr));
	app->WriteProfileInt("FolderViewColor","BkColorB",GetBValue(m_appearance_dlg.m_fv_bg_cr));
	mf->m_pTreeV->GetTreeCtrl().SetBkColor(m_appearance_dlg.m_fv_bg_cr);
	// summaryview̔wiF
	app->WriteProfileInt("SummaryViewColor","BkColorR",GetRValue(m_appearance_dlg.m_sv_bg_cr));
	app->WriteProfileInt("SummaryViewColor","BkColorG",GetGValue(m_appearance_dlg.m_sv_bg_cr));
	app->WriteProfileInt("SummaryViewColor","BkColorB",GetBValue(m_appearance_dlg.m_sv_bg_cr));
	mf->m_pListV->GetListCtrl().SetBkColor(m_appearance_dlg.m_sv_bg_cr);
	mf->m_pListV->GetListCtrl().SetTextBkColor(m_appearance_dlg.m_sv_bg_cr);
	// textview̔wiF
	app->WriteProfileInt("TextViewColor","BkColorR",GetRValue(m_appearance_dlg.m_tv_bg_cr));
	app->WriteProfileInt("TextViewColor","BkColorG",GetGValue(m_appearance_dlg.m_tv_bg_cr));
	app->WriteProfileInt("TextViewColor","BkColorB",GetBValue(m_appearance_dlg.m_tv_bg_cr));
	mf->m_pTextV->GetRichEditCtrl().SetBackgroundColor(FALSE, m_appearance_dlg.m_tv_bg_cr);
	// multipartview̔wiF
	mf->m_pMultiV->GetListCtrl().SetBkColor(m_appearance_dlg.m_tv_bg_cr);
	mf->m_pMultiV->GetListCtrl().SetTextBkColor(m_appearance_dlg.m_tv_bg_cr);
	mf->m_pMultiV->GetListCtrl().RedrawWindow();
	// editviewattachedfileview̔wiF
	app->WriteProfileInt("EditViewColor","BkColorR",GetRValue(m_appearance_dlg.m_ev_bg_cr));
	app->WriteProfileInt("EditViewColor","BkColorG",GetGValue(m_appearance_dlg.m_ev_bg_cr));
	app->WriteProfileInt("EditViewColor","BkColorB",GetBValue(m_appearance_dlg.m_ev_bg_cr));
	for(int i=0; i<app->m_draft_array.GetSize(); i++){
		app->m_draft_array.GetAt(i)->m_pEditV->GetRichEditCtrl().SetBackgroundColor(FALSE, m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetBkColor(m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().RedrawWindow();
	}
	// folderview̃eLXgF	
	app->WriteProfileInt("FolderViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_fv_font_cr));
	app->WriteProfileInt("FolderViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_fv_font_cr));
	app->WriteProfileInt("FolderViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_fv_font_cr));
	mf->m_pTreeV->GetTreeCtrl().SetTextColor(m_appearance_dlg.m_fv_font_cr);
	// summaryview̃eLXgF
	app->WriteProfileInt("SummaryViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_sv_font_cr));
	app->WriteProfileInt("SummaryViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_sv_font_cr));
	app->WriteProfileInt("SummaryViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_sv_font_cr));
	mf->m_pListV->GetListCtrl().SetTextColor(m_appearance_dlg.m_sv_font_cr);
	// textview̃eLXgF
	app->WriteProfileInt("TextViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_tv_font_cr));
	app->WriteProfileInt("TextViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_tv_font_cr));
	app->WriteProfileInt("TextViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_tv_font_cr));
	// textview̃wb_\F
	app->WriteProfileInt("TextViewHdColor","TxtColorR",GetRValue(m_appearance_dlg.m_tv_head_cr));
	app->WriteProfileInt("TextViewHdColor","TxtColorG",GetGValue(m_appearance_dlg.m_tv_head_cr));
	app->WriteProfileInt("TextViewHdColor","TxtColorB",GetBValue(m_appearance_dlg.m_tv_head_cr));
	// multipartview̃eLXgF
	mf->m_pMultiV->GetListCtrl().SetTextColor(m_appearance_dlg.m_tv_font_cr);
	mf->m_pMultiV->GetListCtrl().RedrawWindow();
	// editviewattachedfileview̃eLXgF
	app->WriteProfileInt("EditViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_ev_font_cr));
	app->WriteProfileInt("EditViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_ev_font_cr));
	app->WriteProfileInt("EditViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_ev_font_cr));
	for(i=0; i<app->m_draft_array.GetSize(); i++){
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetTextColor(m_appearance_dlg.m_ev_font_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetTextBkColor(m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().RedrawWindow();
	}
	// eʂ̍XV
	mf->m_pTreeV->GetTreeCtrl().RedrawWindow();
	mf->m_pListV->GetListCtrl().RedrawWindow();
	mf->m_pTextV->GetRichEditCtrl().RedrawWindow();

	// OGfB^̐ݒXV
	CString buf;
	m_other_dlg.m_editor_path.GetWindowText(buf);
	app->WriteProfileString("Editor", "Path", buf);
	buf.Empty();
	// ftHgAJEgݒXV
	m_other_dlg.m_def_account.GetWindowText(buf);
	app->WriteProfileString("DefaultMailBox", "boxname", buf);
	// M̊ԊuݒXV
/*	CString minute;
	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
	if(minute.SpanExcluding("0123456789").IsEmpty()){
		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
	}*/
	CString minute;
	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
	if(minute.SpanExcluding("0123456789").IsEmpty()){
		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
		mf->KillTimer(1);
		if(atoi(minute) >= 1){
			mf->SetTimer(1, atoi(minute)*60000, NULL);
		}
	}

	// font̕ύX
	mf->m_pTextV->SetFontEx(m_appearance_dlg.m_tv_lf);
//	mf->m_pTextV->SetFontColorAndLink();
	app->WriteProfileBinary("TextViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_tv_lf, sizeof(LOGFONT));
	for(i=0; i < app->m_draft_array.GetSize(); i++){
		app->m_draft_array[i]->m_pEditV->SetFontEx(m_appearance_dlg.m_ev_lf);
//		app->m_draft_array[i]->m_pEditV->SetFontColorAndLink();
	}
	app->WriteProfileBinary("EditViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_ev_lf, sizeof(LOGFONT));

	// ^XNgCACRݒ̕ۑ
	int nUseTaskTray = m_other_dlg.m_checkUseTaskTray.GetCheck();
	app->WriteProfileInt(_T("TaskTray"), _T("UseTaskTray"), nUseTaskTray);
	int nTaskTrayOnly = m_other_dlg.m_checkTaskTrayOnly.GetCheck();
	app->WriteProfileInt(_T("TaskTray"), _T("TaskTrayOnly"), nTaskTrayOnly);

	CDialog::OnOK();
}

==> pochy-0.1.6-src.tar.gz: pochy-0.1.6-src/SettingGeneralDlg.cpp <==
/*
 * Copyright (C) 2002-2003 chik, s.hiranaka
 * For license terms, see the file COPYING in this directory.
 */

// SettingGeneralDlg.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "SettingGeneralDlg.h"
#include "SettingGeneralAppearanceDlg.h"
#include "SettingGeneralOtherDlg.h"
#include "MainFrm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CSettingGeneralDlg _CAO


CSettingGeneralDlg::CSettingGeneralDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSettingGeneralDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSettingGeneralDlg)
		//  - ClassWizard ͂̈ʒuɃ}bsOp̃}Nǉ܂͍폜܂B
	//}}AFX_DATA_INIT
}


void CSettingGeneralDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSettingGeneralDlg)
	DDX_Control(pDX, IDC_SETTING_GENERAL_TAB, m_tab);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CSettingGeneralDlg, CDialog)
	//{{AFX_MSG_MAP(CSettingGeneralDlg)
	ON_NOTIFY(TCN_SELCHANGE, IDC_SETTING_GENERAL_TAB, OnSelchangeTab)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSettingGeneralDlg bZ[W nh

BOOL CSettingGeneralDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();
	
	TC_ITEM item;  //^uACe\
	//^uRg[ɍڂ̒ǉ
	item.mask = TCIF_TEXT;
	item.pszText = "FEtHg"; //^ǔo̐ݒ
	m_tab.InsertItem(0, &item); //^uRg[ɍڂ}

	item.pszText = "̑";
	m_tab.InsertItem(1, &item);

	// ^uRg[eEBhEƂĊe^uy[W쐬
	m_appearance_dlg.Create(IDD_SETTING_GENERAL_APPEARANCE, &m_tab);
	m_other_dlg.Create(IDD_SETTING_GENERAL_OTHER, &m_tab);

	//\Ԃ̐ݒ
	m_appearance_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);
	m_other_dlg.SetWindowPos(&wndTop, 2, 20, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);

	m_appearance_dlg.ShowWindow(SW_SHOW);
	m_other_dlg.ShowWindow(SW_HIDE);

	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
}

void CSettingGeneralDlg::OnSelchangeTab(NMHDR* pNMHDR, LRESULT* pResult) 
{
	int index = m_tab.GetCurSel(); //؂ւOTabIndexԍ
	//IꂽTab̂ݕ\B
	switch(index){
	case 0:
		m_appearance_dlg.ShowWindow(SW_SHOW);
		m_other_dlg.ShowWindow(SW_HIDE);
		break;
	case 1:
		m_appearance_dlg.ShowWindow(SW_HIDE);
		m_other_dlg.ShowWindow(SW_SHOW);
		break;
	}

	*pResult = 0;
}

void CSettingGeneralDlg::OnOK() 
{
	CPochyApp* app = (CPochyApp*)AfxGetApp();
	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;

	// folderview̔wiF
	app->WriteProfileInt("FolderViewColor","BkColorR",GetRValue(m_appearance_dlg.m_fv_bg_cr));
	app->WriteProfileInt("FolderViewColor","BkColorG",GetGValue(m_appearance_dlg.m_fv_bg_cr));
	app->WriteProfileInt("FolderViewColor","BkColorB",GetBValue(m_appearance_dlg.m_fv_bg_cr));
	mf->m_pTreeV->GetTreeCtrl().SetBkColor(m_appearance_dlg.m_fv_bg_cr);
	// summaryview̔wiF
	app->WriteProfileInt("SummaryViewColor","BkColorR",GetRValue(m_appearance_dlg.m_sv_bg_cr));
	app->WriteProfileInt("SummaryViewColor","BkColorG",GetGValue(m_appearance_dlg.m_sv_bg_cr));
	app->WriteProfileInt("SummaryViewColor","BkColorB",GetBValue(m_appearance_dlg.m_sv_bg_cr));
	mf->m_pListV->SetReadBkColor(m_appearance_dlg.m_sv_bg_cr);
	mf->m_pListV->SetUnreadBkColor(m_appearance_dlg.m_sv_bg_cr);
	// textview̔wiF
	app->WriteProfileInt("TextViewColor","BkColorR",GetRValue(m_appearance_dlg.m_tv_bg_cr));
	app->WriteProfileInt("TextViewColor","BkColorG",GetGValue(m_appearance_dlg.m_tv_bg_cr));
	app->WriteProfileInt("TextViewColor","BkColorB",GetBValue(m_appearance_dlg.m_tv_bg_cr));
	mf->m_pTextV->GetRichEditCtrl().SetBackgroundColor(FALSE, m_appearance_dlg.m_tv_bg_cr);
	// multipartview̔wiF
	mf->m_pMultiV->GetListCtrl().SetBkColor(m_appearance_dlg.m_tv_bg_cr);
	mf->m_pMultiV->GetListCtrl().SetTextBkColor(m_appearance_dlg.m_tv_bg_cr);
	mf->m_pMultiV->GetListCtrl().RedrawWindow();
	// editviewattachedfileview̔wiF
	app->WriteProfileInt("EditViewColor","BkColorR",GetRValue(m_appearance_dlg.m_ev_bg_cr));
	app->WriteProfileInt("EditViewColor","BkColorG",GetGValue(m_appearance_dlg.m_ev_bg_cr));
	app->WriteProfileInt("EditViewColor","BkColorB",GetBValue(m_appearance_dlg.m_ev_bg_cr));
	for(int i=0; i<app->m_draft_array.GetSize(); i++){
		app->m_draft_array.GetAt(i)->m_pEditV->GetRichEditCtrl().SetBackgroundColor(FALSE, m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetBkColor(m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().RedrawWindow();
	}
	// folderview̃eLXgF	
	app->WriteProfileInt("FolderViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_fv_font_cr));
	app->WriteProfileInt("FolderViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_fv_font_cr));
	app->WriteProfileInt("FolderViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_fv_font_cr));
	mf->m_pTreeV->GetTreeCtrl().SetTextColor(m_appearance_dlg.m_fv_font_cr);
	// summaryview̃eLXgF
	app->WriteProfileInt("SummaryViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_sv_font_cr));
	app->WriteProfileInt("SummaryViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_sv_font_cr));
	app->WriteProfileInt("SummaryViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_sv_font_cr));
 	mf->m_pListV->SetReadTextColor(m_appearance_dlg.m_sv_font_cr);
 	mf->m_pListV->SetUnreadTextColor(m_appearance_dlg.m_sv_font_cr);
	// textview̃eLXgF
	app->WriteProfileInt("TextViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_tv_font_cr));
	app->WriteProfileInt("TextViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_tv_font_cr));
	app->WriteProfileInt("TextViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_tv_font_cr));
	// textview̃wb_\F
	app->WriteProfileInt("TextViewHdColor","TxtColorR",GetRValue(m_appearance_dlg.m_tv_head_cr));
	app->WriteProfileInt("TextViewHdColor","TxtColorG",GetGValue(m_appearance_dlg.m_tv_head_cr));
	app->WriteProfileInt("TextViewHdColor","TxtColorB",GetBValue(m_appearance_dlg.m_tv_head_cr));
	// multipartview̃eLXgF
	mf->m_pMultiV->GetListCtrl().SetTextColor(m_appearance_dlg.m_tv_font_cr);
	mf->m_pMultiV->GetListCtrl().RedrawWindow();
	// editviewattachedfileview̃eLXgF
	app->WriteProfileInt("EditViewColor","TxtColorR",GetRValue(m_appearance_dlg.m_ev_font_cr));
	app->WriteProfileInt("EditViewColor","TxtColorG",GetGValue(m_appearance_dlg.m_ev_font_cr));
	app->WriteProfileInt("EditViewColor","TxtColorB",GetBValue(m_appearance_dlg.m_ev_font_cr));
	for(i=0; i<app->m_draft_array.GetSize(); i++){
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetTextColor(m_appearance_dlg.m_ev_font_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().SetTextBkColor(m_appearance_dlg.m_ev_bg_cr);
		app->m_draft_array.GetAt(i)->m_pListV2->GetListCtrl().RedrawWindow();
	}
	// eʂ̍XV
	mf->m_pTreeV->GetTreeCtrl().RedrawWindow();
	mf->m_pListV->GetListCtrl().RedrawWindow();
	mf->m_pTextV->GetRichEditCtrl().RedrawWindow();

	// OGfB^̐ݒXV
	CString buf;
	m_other_dlg.m_editor_path.GetWindowText(buf);
	app->WriteProfileString("Editor", "Path", buf);
	buf.Empty();
	// ftHgAJEgݒXV
	m_other_dlg.m_def_account.GetWindowText(buf);
	app->WriteProfileString("DefaultMailBox", "boxname", buf);
	// M̊ԊuݒXV
/*	CString minute;
	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
	if(minute.SpanExcluding("0123456789").IsEmpty()){
		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
	}*/
	CString minute;
	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
	if(minute.SpanExcluding("0123456789").IsEmpty()){
		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
		mf->KillTimer(1);
		if(atoi(minute) >= 1){
			mf->SetTimer(1, atoi(minute)*60000, NULL);
		}
	}

	// font̕ύX
	mf->m_pTextV->SetFontEx(m_appearance_dlg.m_tv_lf);
//	mf->m_pTextV->SetFontColorAndLink();
	app->WriteProfileBinary("TextViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_tv_lf, sizeof(LOGFONT));
	for(i=0; i < app->m_draft_array.GetSize(); i++){
		app->m_draft_array[i]->m_pEditV->SetFontEx(m_appearance_dlg.m_ev_lf);
//		app->m_draft_array[i]->m_pEditV->SetFontColorAndLink();
	}
	app->WriteProfileBinary("EditViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_ev_lf, sizeof(LOGFONT));

	// ^XNgCACRݒ̕ۑ
	int nUseTaskTray = m_other_dlg.m_checkUseTaskTray.GetCheck();
	app->WriteProfileInt(_T("TaskTray"), _T("UseTaskTray"), nUseTaskTray);
	int nTaskTrayOnly = m_other_dlg.m_checkTaskTrayOnly.GetCheck();
	app->WriteProfileInt(_T("TaskTray"), _T("TaskTrayOnly"), nTaskTrayOnly);

	CDialog::OnOK();
}
